@@ -1,6 +1,3 @@
-from sqlalchemy import MetaData
-from sqlalchemy.orm import declarative_base
-
 from ..provider import ServiceProvider
 
 
@@ -26,3 +23,4 @@ class DependencyContainer:
     def cleanup(cls):
         if hasattr(cls, 'Instance') and cls.Instance is not None:
             del cls.Instance
+            cls.Instance = None
